@@ -1,5 +1,5 @@
 testthat::test_that(
-  desc = "Boxplot-View toggled saved in rv",
+  desc = "Reactivity in C module is working",
   code = {
     suppressMessages({
       rv <- eCerto:::test_rv()
@@ -16,8 +16,8 @@ testthat::test_that(
           session$setInputs(certification_view=c("dataview", "stats", "CertValPlot"))
           testthat::expect_equal(input$certification_view,c("dataview","stats","CertValPlot"))
           # the rv object is updated if Fig_width parameter is modified
-          session$setInputs(Fig01_width=450)
-          testthat::expect_equal(eCerto::getValue(rv, c("Certification_processing","CertValPlot","Fig01_width")), 450)
+          #session$setInputs(Fig01_height=450)
+          #testthat::expect_equal(eCerto::getValue(rv, c("Certification_processing","CertValPlot","Fig01_height")), 450)
         }
       )
     })
